Struct frame::traits::StorageVersion
pub struct StorageVersion(_);Expand description
The storage version of a pallet.
Each storage version of a pallet is stored in the state under a fixed key. See
STORAGE_VERSION_STORAGE_KEY_POSTFIX for how this key is built.
Implementations
impl StorageVersion
impl StorageVersion
pub const fn new(version: u16) -> StorageVersion
pub const fn new(version: u16) -> StorageVersion
Creates a new instance of Self.
pub fn storage_key<P>() -> [u8; 32]where
P: PalletInfoAccess,
pub fn storage_key<P>() -> [u8; 32]where P: PalletInfoAccess,
Returns the storage key for a storage version.
See STORAGE_VERSION_STORAGE_KEY_POSTFIX on how this key is built.
pub fn put<P>(&self)where
P: PalletInfoAccess,
pub fn put<P>(&self)where P: PalletInfoAccess,
Put this storage version for the given pallet into the storage.
It will use the storage key that is associated with the given Pallet.
Panics
This function will panic iff Pallet can not be found by PalletInfo.
In a runtime that is put together using
construct_runtime! this should never happen.
It will also panic if this function isn’t executed in an externalities provided environment.
pub fn get<P>() -> StorageVersionwhere
P: PalletInfoAccess,
pub fn get<P>() -> StorageVersionwhere P: PalletInfoAccess,
Get the storage version of the given pallet from the storage.
It will use the storage key that is associated with the given Pallet.
Panics
This function will panic iff Pallet can not be found by PalletInfo.
In a runtime that is put together using
construct_runtime! this should never happen.
It will also panic if this function isn’t executed in an externalities provided environment.