Trait frame::traits::ContainsPair
pub trait ContainsPair<A, B> {
// Required method
fn contains(a: &A, b: &B) -> bool;
}Expand description
A trait for querying whether a type can be said to “contain” a pair-value.
pub trait ContainsPair<A, B> {
// Required method
fn contains(a: &A, b: &B) -> bool;
}A trait for querying whether a type can be said to “contain” a pair-value.