pub trait EstimateCallFee<Call, Balance> {
    // Required method
    fn estimate_call_fee(call: &Call, post_info: PostDispatchInfo) -> Balance;
}
Something that can estimate the fee of a (frame-based) call.

Typically, the same pallet that will charge transaction fees will implement this.

Required Methods

fn estimate_call_fee(call: &Call, post_info: PostDispatchInfo) -> Balance

Estimate the fee of this call.

The dispatch info and the length is deduced from the call. The post info can optionally be provided.

Implementors



impl<Call, Balance, const T: u32> EstimateCallFee<Call, Balance> for ConstU32<T>where Balance: From<u32>,