Trait frame::traits::WhitelistedStorageKeys
pub trait WhitelistedStorageKeys {
// Required method
fn whitelisted_storage_keys() -> Vec<TrackedStorageKey, Global>;
}Expand description
Allows a pallet to specify storage keys to whitelist during benchmarking. This means those keys will be excluded from the benchmarking performance calculation.
Required Methods
fn whitelisted_storage_keys() -> Vec<TrackedStorageKey, Global>
fn whitelisted_storage_keys() -> Vec<TrackedStorageKey, Global>
Returns a Vec<TrackedStorageKey> indicating the storage keys that
should be whitelisted during benchmarking. This means that those keys
will be excluded from the benchmarking performance calculation.